module WeatherModel
  module SourceSchema
    AqiForecast = 
      {
        sort: 'Aqi',
        table_name: :aqi_forecasts,
        schema: {
          datetime: :datetime,
          prompt: :string,
          list: :text
        },
        options: {
          index: %i[datetime],
          expire: 2 * 24 * 60 * 60,
          unique: nil,
          belongs_to: nil,
          has_many: nil,
          json_column: :list
        },
        factory_name: :aqi_forecast,
        factory: {
          datetime: Time.parse('2011-11-11 11:11'),
          prompt: '',
          list: [
                  {
                    "period"=>"今天夜间（20时—06时）",
                    "aqi"=>"35-55",
                    "level"=>"优到良",
                    "pripoll"=>"PM10"
                  }, {
                    "period"=>"明天上午（06时—12时）",
                    "aqi"=>"35-55",
                    "level"=>"优到良",
                    "pripoll"=>"PM10"
                  }, {
                    "period"=>"明天下午（12时—20时）",
                    "aqi"=>"45-65",
                    "level"=>"优到良",
                    "pripoll"=>"O3"
                  }, {
                    "period"=>"明天夜间（20时—06时）",
                    "aqi"=>"35-55",
                    "level"=>"优到良",
                    "pripoll"=>"PM10"
                  }, {
                    "period"=>"后天白天（06时—20时）",
                    "aqi"=>"55-75",
                    "level"=>"良",
                    "pripoll"=>"O3"
                  }
                ]
        }
      }

    RealtimeAqi = 
      {
        sort: 'Aqi',
        table_name: :realtime_aqi,
        schema: {
          datetime: :datetime,
          aqi: :string,
          level: :string,
          pripoll: :string,
          content: :string,
          measure: :string,
        },
        options: {
          index: %i[datetime],
          expire: 3 * 24 * 60 * 60,
          unique: nil,
          belongs_to: nil,
          has_many: nil,
          json_column: :msg
        },
        factory_name: :realtime_aqi,
        factory: {
          datetime: Time.parse('2011-11-11 11:11'),
          aqi: '54',
          level: '良',
          pripoll: 'PM10',
          msg: {
            content: '空气质量可接受，但某些污染物可能对极少数异常敏感人群健康有较弱影响。',
            measure: '建议措施极少数异常敏感人群应减少户外活动。'
          }
        }
      }
  end
end 
